#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
from cpt.packager import ConanMultiPackager


def get_travis_branch():
    return os.getenv("TRAVIS_BRANCH")


def get_reference():
    return "CTRE/{}".format(get_travis_branch())


if __name__ == "__main__":
    builder = ConanMultiPackager(
        reference=get_reference(),
        username="ctre",
        upload="https://api.bintray.com/conan/hanickadot/ctre",
        upload_only_when_stable=True,
        stable_branch_pattern="v?\d+\.\d+.*",
        test_folder=os.path.join(".conan", "test_package"))
    builder.add_common_builds()
    builder.run()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from conans import ConanFile


class CtreConan(ConanFile):
    name = "CTRE"
    license = "Apache 2.0 with LLVM Exception"
    url = "https://github.com/hanickadot/compile-time-regular-expressions"
    author = "Hana Dusíková (ctre@hanicka.net)"
    description = "Compile Time Regular Expression for C++17/20"
    homepage = "https://github.com/hanickadot/compile-time-regular-expressions"
    no_copy_source = True
    scm = {
        "type": "git",
        "url": "auto",
        "revision": "auto"
    }
    
    def package(self):
        self.copy("LICENSE", "licenses")
        self.copy("*.hpp")
    
    def package_id(self):
        self.info.header_only()

